@@ -108,8 +108,9 @@ async def checkHLSQueue(opqueue, gsdbs, source, onframe):
             await onframe(gsdbs, source, data, 0)
 
 
-async def createHLSPlayer(gsdbs, onframe,source, ondestruct, playlisturl):
+async def createHLSPlayer(gsdbs, onframe, source, ondestruct, playlisturl):
     hlsqueue = asyncio.Queue(3)
     hlsplayer = GSHLSPlayerNew(gsdbs, onframe=onframe, ondestruct=ondestruct, url=playlisturl, queue=hlsqueue)
-    return asyncio.gather(hlsplayer.startrecording(),
-                          checkHLSQueue(hlsqueue, gsdbs, source, onframe))
+    hlstask = await asyncio.gather(hlsplayer.startrecording(),
+                                   checkHLSQueue(hlsqueue, gsdbs, source, onframe))
+    return hlstask
