@@ -154,7 +154,7 @@ class GSPeerConnectionWatcherNew:
 
     @classmethod
     async def create(cls, connectionWatcher, gsdbs, target, onframe=None, onmessage=None, ontrack=None,
-                     ontrackended=None):
+                     ontrackended=None,  signalingserver=None):
         self = connectionWatcher
         self.rtconfiList = []
         self.sio = socketio.AsyncClient()
@@ -166,6 +166,7 @@ class GSPeerConnectionWatcherNew:
         self.onmessage = onmessage
         self.ontrack = ontrack
         self.ontrackended = ontrackended
+        self.signalingserver = signalingserver
         self.logger = logging.getLogger(__name__)
 
         if self.gsdbs.credentials["stunenable"]:
@@ -287,10 +288,14 @@ class GSPeerConnectionWatcherNew:
                 await self.gsmediaconsumer.stop()
             await self.ontrackended(self.gsdbs, target)
 
-        if "localhost" in self.gsdbs.credentials["signalserver"]:
-            connectURL = f'{self.gsdbs.credentials["signalserver"]}:{str(self.gsdbs.credentials["signalport"])}'
+        if self.signalingserver is not None:
+            connectURL = self.signalingserver
+
         else:
-            connectURL = self.gsdbs.credentials["signalserver"]
+            if "localhost" in self.gsdbs.credentials["signalserver"]:
+                connectURL = f'{self.gsdbs.credentials["signalserver"]}:{str(self.gsdbs.credentials["signalport"])}'
+            else:
+                connectURL = self.gsdbs.credentials["signalserver"]
 
         await self.sio.connect(
             f'{connectURL}?gssession={self.gsdbs.cookiejar.get("session")}.{self.gsdbs.cookiejar.get("signature")}{self.gsdbs.credentials["cnode"]}&target={self.target}&terminator=true')
